#!/usr/bin/env ruby

require "benchmark"
require "pathname"

base_dir = (Pathname(File.dirname(__FILE__)) + "..").expand_path
$LOAD_PATH.unshift((base_dir + "lib").to_s)

require "rss"

n = 10

setup_maker = Proc.new do |maker|
  maker.channel.id = "XXX"
  maker.channel.updated = Time.now
  maker.channel.author = "Alice"
  maker.channel.title = "Benchmark Feed"
  maker.channel.about = "http://localhost/"
  maker.channel.link = "http://localhost/index.rdf"
  maker.channel.description = "A sample feed for benchmark"

  maker.items.new_item do |item|
    item.link = "http://localhost/1"
    item.title = "1 item"
    item.updated = Time.now
  end
end

GC.disable
Benchmark.bmbm(20) do |benchmark|
  benchmark.report("RSS::Maker: #{n}x: RSS 1.0") do
    n.times do
      RSS::Maker.make("rss1.0", &setup_maker)
    end
  end

  benchmark.report("RSS::Maker: #{n}x: RSS 2.0") do
    n.times do
      RSS::Maker.make("rss2.0", &setup_maker)
    end
  end

  benchmark.report("RSS::Maker: #{n}x: Atom(feed)") do
    n.times do
      RSS::Maker.make("atom:feed", &setup_maker)
    end
  end

  benchmark.report("RSS::Maker: #{n}x: Atom(entry)") do
    n.times do
      RSS::Maker.make("atom:entry", &setup_maker)
    end
  end
end
